@@ -23,7 +23,7 @@ def sct(x, y, x_axis, y_axis, title, **kwargs):
     return plt
 
 
-def sct(x, y, u, v, x_axis, y_axis, title, **kwargs):
+def quiver(x, y, u, v, x_axis, y_axis, title, **kwargs):
     plt.quiver(x, y, u, v**kwargs)
     plt.xlabel(x_axis)
     plt.ylabel(y_axis)
